I bought my Raspberry Pi (with a transparent case) 2 weeks ago. Since its tiny size and low power consumption, I decided to run it in 7x24 as a light weight server.
When the Pi was just delivered, my Dad wondered its ability. Don't under estimate the configuration of it. I called it a "server" means it really fulfill my expectation.
Once I recieved it, what have I done to it:
Contains technical document about Unix/Linux, Java, Python, Raspberry Pi and other IT related topics. Not a full tutorial but as a quick reference guide
Friday, November 16, 2012
Friday, October 26, 2012
Check utilization for Solaris 10
Seems "top" is not available (or not installed by default). Actually there is another command "prstat" which provide similar but more powerful functions:
#prstat -Z
PID USERNAME SIZE RSS STATE PRI NICE TIME CPU PROCESS/NLWP
5147 root 206M 33M sleep 59 0 0:03:10 0.0% webservd/30
1378 noaccess 157M 129M sleep 59 0 0:02:41 0.0% java/18
2333 root 130M 90M sleep 59 0 0:07:52 0.0% java/72
5060 root 82M 14M sleep 59 0 0:03:11 0.0% webservd/71
5088 106 81M 20M sleep 59 0 0:03:11 0.0% webservd/72
1865 root 63M 24M sleep 101 - 0:00:04 0.0% rgmd/43
1009 root 51M 24M sleep 59 0 0:00:22 0.0% fmd/30
1719 root 48M 4080K sleep 100 - 0:00:19 0.0% rpc.pmfd/23
1119 root 44M 28M sleep 59 0 0:34:05 0.0% poold/8
11 root 36M 29M sleep 59 0 0:00:30 0.0% svc.startd/13
5094 root 34M 16M sleep 59 0 0:00:50 0.0% opceca/2
861 root 28M 3520K sleep 59 0 0:00:00 0.0% pmmd/20
5146 root 26M 3344K sleep 59 0 0:00:07 0.0% webservd/2
5087 root 26M 2976K sleep 59 0 0:00:07 0.0% webservd/2
5059 root 26M 2600K sleep 59 0 0:00:07 0.0% webservd/2
ZONEID NPROC SWAP RSS MEMORY TIME CPU ZONE
0 95 734M 566M 0.9% 1:05:10 0.0% global
1 37 275M 112M 0.2% 0:10:00 0.0% zone1
3 44 113M 112M 0.2% 3:18:50 0.1% zone2
2 23 18M 26M 0.0% 0:01:21 0.0% zone3
Total: 199 processes, 4159 lwps, load averages: 0.43, 0.39, 0.38
Note that I run this command one a container with 3 zones. The -Z parameter provide a glance of the utilization of each zone. To view the utilization of an individual zone, you can run "prstat -z":
#prstat -Z
PID USERNAME SIZE RSS STATE PRI NICE TIME CPU PROCESS/NLWP
5147 root 206M 33M sleep 59 0 0:03:10 0.0% webservd/30
1378 noaccess 157M 129M sleep 59 0 0:02:41 0.0% java/18
2333 root 130M 90M sleep 59 0 0:07:52 0.0% java/72
5060 root 82M 14M sleep 59 0 0:03:11 0.0% webservd/71
5088 106 81M 20M sleep 59 0 0:03:11 0.0% webservd/72
1865 root 63M 24M sleep 101 - 0:00:04 0.0% rgmd/43
1009 root 51M 24M sleep 59 0 0:00:22 0.0% fmd/30
1719 root 48M 4080K sleep 100 - 0:00:19 0.0% rpc.pmfd/23
1119 root 44M 28M sleep 59 0 0:34:05 0.0% poold/8
11 root 36M 29M sleep 59 0 0:00:30 0.0% svc.startd/13
5094 root 34M 16M sleep 59 0 0:00:50 0.0% opceca/2
861 root 28M 3520K sleep 59 0 0:00:00 0.0% pmmd/20
5146 root 26M 3344K sleep 59 0 0:00:07 0.0% webservd/2
5087 root 26M 2976K sleep 59 0 0:00:07 0.0% webservd/2
5059 root 26M 2600K sleep 59 0 0:00:07 0.0% webservd/2
ZONEID NPROC SWAP RSS MEMORY TIME CPU ZONE
0 95 734M 566M 0.9% 1:05:10 0.0% global
1 37 275M 112M 0.2% 0:10:00 0.0% zone1
3 44 113M 112M 0.2% 3:18:50 0.1% zone2
2 23 18M 26M 0.0% 0:01:21 0.0% zone3
Total: 199 processes, 4159 lwps, load averages: 0.43, 0.39, 0.38
Note that I run this command one a container with 3 zones. The -Z parameter provide a glance of the utilization of each zone. To view the utilization of an individual zone, you can run "prstat -z
Thursday, October 25, 2012
Change network speed and duplex mode on Solaris 10
When I try to FTP some files using an interface, the speed is unexpectedly slow. Then I try to see the network interfaces status:
root@sunserver # dladm show-dev
nxge0 link: down speed: 0 Mbps duplex: unknown
nxge1 link: down speed: 0 Mbps duplex: unknown
nxge2 link: unknown speed: 0 Mbps duplex: unknown
nxge3 link: unknown speed: 0 Mbps duplex: unknown
igb0 link: up speed: 100 Mbps duplex: half
igb1 link: unknown speed: 0 Mbps duplex: half
igb2 link: up speed: 100 Mbps duplex: full
igb3 link: up speed: 1000 Mbps duplex: full
Seems 100 Half is a wrong setting. Since the speed is set by auto negotiation mode, we have to change it manually:
First, check the interface properties by "ndd":
root@sunserver # ndd -get /dev/igb0 ?
? (read only)
mtu (read and write)
min_allowed_mtu (read only)
max_allowed_mtu (read only)
adv_autoneg_cap (read and write)
adv_1000fdx_cap (read and write)
adv_1000hdx_cap (read only)
adv_100fdx_cap (read and write)
adv_100hdx_cap (read and write)
adv_10fdx_cap (read and write)
adv_10hdx_cap (read and write)
adv_100T4_cap (read only)
link_status (read only)
link_speed (read only)
link_duplex (read only)
autoneg_cap (read only)
pause_cap (read only)
asym_pause_cap (read only)
1000fdx_cap (read only)
1000hdx_cap (read only)
100fdx_cap (read only)
100hdx_cap (read only)
10fdx_cap (read only)
10hdx_cap (read only)
lp_autoneg_cap (read only)
lp_pause_cap (read only)
lp_asym_pause_cap (read only)
lp_1000hdx_cap (read only)
lp_1000fdx_cap (read only)
lp_100fdx_cap (read only)
lp_100hdx_cap (read only)
lp_10fdx_cap (read only)
lp_10hdx_cap (read only)
link_autoneg (read only)
tx_copy_thresh (read and write)
tx_recycle_thresh (read and write)
tx_overload_thresh (read and write)
tx_resched_thresh (read and write)
rx_copy_thresh (read and write)
rx_limit_per_intr (read and write)
intr_throttling (read and write)
adv_pause_cap (read only)
adv_asym_pause_cap (read only)
As those "read only" properties are not useful, let's filter out further:
root@sunserver # dladm show-dev
nxge0 link: down speed: 0 Mbps duplex: unknown
nxge1 link: down speed: 0 Mbps duplex: unknown
nxge2 link: unknown speed: 0 Mbps duplex: unknown
nxge3 link: unknown speed: 0 Mbps duplex: unknown
igb0 link: up speed: 100 Mbps duplex: half
igb1 link: unknown speed: 0 Mbps duplex: half
igb2 link: up speed: 100 Mbps duplex: full
igb3 link: up speed: 1000 Mbps duplex: full
Seems 100 Half is a wrong setting. Since the speed is set by auto negotiation mode, we have to change it manually:
First, check the interface properties by "ndd":
root@sunserver # ndd -get /dev/igb0 ?
? (read only)
mtu (read and write)
min_allowed_mtu (read only)
max_allowed_mtu (read only)
adv_autoneg_cap (read and write)
adv_1000fdx_cap (read and write)
adv_1000hdx_cap (read only)
adv_100fdx_cap (read and write)
adv_100hdx_cap (read and write)
adv_10fdx_cap (read and write)
adv_10hdx_cap (read and write)
adv_100T4_cap (read only)
link_status (read only)
link_speed (read only)
link_duplex (read only)
autoneg_cap (read only)
pause_cap (read only)
asym_pause_cap (read only)
1000fdx_cap (read only)
1000hdx_cap (read only)
100fdx_cap (read only)
100hdx_cap (read only)
10fdx_cap (read only)
10hdx_cap (read only)
lp_autoneg_cap (read only)
lp_pause_cap (read only)
lp_asym_pause_cap (read only)
lp_1000hdx_cap (read only)
lp_1000fdx_cap (read only)
lp_100fdx_cap (read only)
lp_100hdx_cap (read only)
lp_10fdx_cap (read only)
lp_10hdx_cap (read only)
link_autoneg (read only)
tx_copy_thresh (read and write)
tx_recycle_thresh (read and write)
tx_overload_thresh (read and write)
tx_resched_thresh (read and write)
rx_copy_thresh (read and write)
rx_limit_per_intr (read and write)
intr_throttling (read and write)
adv_pause_cap (read only)
adv_asym_pause_cap (read only)
As those "read only" properties are not useful, let's filter out further:
Thursday, October 11, 2012
SUN Cluster (3.3) installation screen dump
Just a screen dump of the installation. Assumed the Solaris 10 is installed and media of the cluster is ready.
Just a screen dump of the installation. Assumed the Solaris 10 is installed and media of the cluster is ready. # cd# ./installer Unable to access a usable display on the remote system. Continue in command-line mode?(Y/N) Y Java Accessibility Bridge for GNOME loaded.
Monday, October 08, 2012
Symmetrix Command Line
My current job needs to take care of some EMC storages, from DMX to VMAX (also some Clariion/VNX and Celerra). Since I forget all the symcli commands, I created the following tables for quick reference (the table will be updated time to time...) :
symcfg
list -sid
|
|
symcfg
list -sid
|
|
symcfg
list -sid
symcfg
list -sid
symcfg
list -sid
|
|
symcfg
-dir all list -sid
symcfg
-dir all list -sid
symcfg
-dir all list -sid
|
|
symcfg -sa all list -sid
symcfg -da all list -sid
|
SA:
fc address
DA:
disk address
|
symcfg
-fa all list -sid
symcfg
-fa all list -sid
|
check
wwn and fibre connection
|
symcfg -sid
|
Memory
board
|
symcfg
list -upatches -sid
|
Patches
|
symcfg
-sid
symcfg show -sid
|
Hardware
check
|
symcfg
list -pools -sid
symcfg list -pools -sid
|
|
symcfg
list -pools -sid 3281 -gb -detail -thin
|
Thin
pool only
|
symcfg list -datadev -sid 1226
symcfg list -datadev -sid 1226 -range
0000:0001
symcfg list -datadev -sid 1226 -range
0000:0001 -dev
symcfg show -pool <> -thin -gb -detail
|
Thin pool only |
symcfg -sid $SID list -rdfg all
symcfg -sid $SID list -rdfg all -rdfa
|
|
symconfigure -sid $SID list -freespace
|
|
symdev list -sid $SID -da all -space
symdev
list -FA 7E -sid $SID (can use symcfg list -dir ALL to check)
symdisk list -sid $SID -da <> (can use
sycmfg list -da all to check)
|
|
sympd
list -sid $SID
sympd list -sid $SID -v
|
|
symdev
list -inventory
|
|
symdisk
-sid $SID show 7A:C4
symdisk list -sid $SID -da
symdisk
list -sid $SID -by_diskgroup
|
Subscribe to:
Posts (Atom)